# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-08-29 12:53
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('currency_history', '0002_auto_20170804_0933'),
    ]

    operations = [
        migrations.AddField(
            model_name='currencyratehistory',
            name='fixed',
            field=models.BooleanField(default=False, verbose_name='Fixed'),
        ),
    ]
